@@ -1,4 +1,4 @@
-#  Author: Roberto Cavada <cavada@irst.itc.it>
+#  Author: Roberto Cavada <cavada@fbk.eu>
 #
 #  Copyright (c) 2005 by Roberto Cavada
 #
@@ -18,13 +18,13 @@
 #  Boston, MA 02110, USA.
 #
 #  For more information on pygtkmvc see <http://pygtkmvc.sourceforge.net>
-#  or email to the author Roberto Cavada <cavada@irst.itc.it>.
-#  Please report bugs to <cavada@irst.itc.it>.
+#  or email to the author Roberto Cavada <cavada@fbk.eu>.
+#  Please report bugs to <cavada@fbk.eu>.
 
 
-__all__ = ["model", "view", "controller", "observable", "observer"]
+__all__ = ["model", "view", "controller", "observable", "observer", "support"]
 
-__version = (1,2,1)
+__version = (1,2,2)
 
 from model import Model, TreeStoreModel, ListStoreModel, TextBufferModel
 from model_mt import ModelMT
