@@ -1,4 +1,4 @@
-#  Author: Roberto Cavada <cavada@irst.itc.it>
+#  Author: Roberto Cavada <cavada@fbk.eu>
 #
 #  Copyright (c) 2005 by Roberto Cavada
 #
@@ -18,8 +18,9 @@
 #  Boston, MA 02110, USA.
 #
 #  For more information on pygtkmvc see <http://pygtkmvc.sourceforge.net>
-#  or email to the author Roberto Cavada <cavada@irst.itc.it>.
-#  Please report bugs to <cavada@irst.itc.it>.
+#  or email to the author Roberto Cavada <cavada@fbk.eu>.
+#  Please report bugs to <cavada@fbk.eu>.
 
 
-__all__ = ["metaclass_base", "metaclasses", "wrappers", "decorators"]
+__all__ = ["metaclass_base", "metaclasses", "wrappers", "decorators",
+           "factories"]
